app/soc/views/sitemap/sidebar.py
changeset 703 c4f3997becd9
parent 697 190b65431579
child 704 8647e6b441fc
--- a/app/soc/views/sitemap/sidebar.py	Sun Dec 07 15:29:10 2008 +0000
+++ b/app/soc/views/sitemap/sidebar.py	Sun Dec 07 15:29:37 2008 +0000
@@ -63,10 +63,10 @@
     sidebar_defaults: The sidebar_defaults are used to construct the
       sidebar items for this View. It is expected to be a tuple of
       three items, the item's url, it's menu_text, and it's
       access_type, see getSidebarLinks on how access_type is used.
     sidebar_additional: The sidebar_additional values are appended
       to the list of items verbatim, and should be in the format
-      expected by getSidebarLinks.
+      expected by getSidebarMenus.
 
   Args:
     params: a dict with params for this View.
@@ -92,7 +92,7 @@
   return result
 
 
-def getSidebarLinks(request, params=None):
+def getSidebarMenus(request, params=None):
   """Returns an dictionary with one sidebar entry.
 
   Calls getSidebarItems to retrieve the items that should be in the
@@ -63,10 +63,10 @@
       sidebar items for this View. It is expected to be a tuple of
       three items, the item's url, it's menu_text, and it's
-      access_type, see getSidebarLinks on how access_type is used.
+      access_type, see getSidebarMenus on how access_type is used.
     sidebar_additional: The sidebar_additional values are appended
       to the list of items verbatim, and should be in the format